==> tyrus-monitoring-jmx-1.10-sources.jar: org/glassfish/tyrus/ext/monitoring/jmx/EndpointMXBean.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.tyrus.ext.monitoring.jmx;

import java.util.List;

import org.glassfish.tyrus.core.Beta;

/**
 * MXBean used for accessing monitored endpoint properties - endpoint path and class name, number of currently open sessions,
 * maximal number of open sessions since the start of monitoring, and message statistics.
 *
 * @author Petr Janouch (petr.janouch at oracle.com)
 * @see MessageStatisticsMXBean
 */
@Beta
public interface EndpointMXBean extends BaseMXBean {

    /**
     * Get the path the endpoint is registered on.
     *
     * @return path of the endpoint.
     */
    public String getEndpointPath();

    /**
     * Get the class name of the endpoint.
     *
     * @return the class name of the endpoint.
     */
    public String getEndpointClassName();

    /**
     * Get the number of sessions currently open on the endpoint.
     *
     * @return the number of sessions currently open on the endpoint.
     */
    public int getOpenSessionsCount();

    /**
     * Get the maximal number of open sessions on the endpoint since the start of monitoring.
     *
     * @return the maximal number of open sessions on the endpoint since the start of monitoring.
     */
    public int getMaximalOpenSessionsCount();

    /**
     * Get list of MXBeans representing currently open sessions. Return an empty list if monitoring is conducted only
     * on endpoint level.
     *
     * @return list of MXBeans representing currently open sessions.
     */
    public List<SessionMXBean> getSessionMXBeans();
}

==> tyrus-monitoring-jmx-1.14-sources.jar: org/glassfish/tyrus/ext/monitoring/jmx/EndpointMXBean.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2014-2016 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.tyrus.ext.monitoring.jmx;

import java.util.List;

import org.glassfish.tyrus.core.Beta;

/**
 * MXBean used for accessing monitored endpoint properties - endpoint path and class name, number of currently open
 * sessions, maximal number of open sessions since the start of monitoring, and message statistics.
 *
 * @author Petr Janouch
 * @see MessageStatisticsMXBean
 */
@Beta
public interface EndpointMXBean extends BaseMXBean {

    /**
     * Get the path the endpoint is registered on.
     *
     * @return path of the endpoint.
     */
    public String getEndpointPath();

    /**
     * Get the class name of the endpoint.
     *
     * @return the class name of the endpoint.
     */
    public String getEndpointClassName();

    /**
     * Get the number of sessions currently open on the endpoint.
     *
     * @return the number of sessions currently open on the endpoint.
     */
    public int getOpenSessionsCount();

    /**
     * Get the maximal number of open sessions on the endpoint since the start of monitoring.
     *
     * @return the maximal number of open sessions on the endpoint since the start of monitoring.
     */
    public int getMaximalOpenSessionsCount();

    /**
     * Get list of MXBeans representing currently open sessions. Return an empty list if monitoring is conducted only on
     * endpoint level.
     *
     * @return list of MXBeans representing currently open sessions.
     */
    public List<SessionMXBean> getSessionMXBeans();
}
